@@ -1,5 +1,6 @@
-from grai_schemas.models import GraiNodeMetadata, GraiEdgeMetadata
 from typing import Union
+
+from grai_schemas.models import GraiEdgeMetadata, GraiNodeMetadata
 from pydantic import BaseModel
 
 
